pub struct SealedSenderDecryptionError {
pub inner: SignalProtocolError,
pub sender: Option<ProtocolAddress>,
}Expand description
Error thrown when the sealed sending decryption fails.
The USMC sender field is only populated when the USMC could be validated against the trust roots; hence the sender information can be trusted, give or take an active attacker on the Signal side.
Fields
inner: SignalProtocolErrorsender: Option<ProtocolAddress>Trait Implementations
Sourceimpl Debug for SealedSenderDecryptionError
impl Debug for SealedSenderDecryptionError
Sourceimpl Error for SealedSenderDecryptionError
impl Error for SealedSenderDecryptionError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl From<SealedSenderDecryptionError> for ServiceError
impl From<SealedSenderDecryptionError> for ServiceError
Sourcefn from(source: SealedSenderDecryptionError) -> Self
fn from(source: SealedSenderDecryptionError) -> Self
Converts to this type from the input type.
Sourceimpl From<SignalProtocolError> for SealedSenderDecryptionError
impl From<SignalProtocolError> for SealedSenderDecryptionError
Sourcefn from(e: SignalProtocolError) -> Self
fn from(e: SignalProtocolError) -> Self
Converts to this type from the input type.